@@ -47,25 +47,22 @@ Fl_Button	*btn_309_date_time = (Fl_Button *)0;
 Fl_Button	*btn_309_export_csv = (Fl_Button *)0;
 
 Fl_Group	*tab_309_2 = (Fl_Group *)0;
-Fl_Input2	*txt_309_comm_time[60] = {(Fl_Input2 *)0};
-Fl_Button	*btn_309_comm_time[60] = {(Fl_Button *)0};
-Fl_Input2	*txt_309_comm_from[60] = {(Fl_Input2 *)0};
-Fl_Input2	*txt_309_comm_to[60]   = {(Fl_Input2 *)0};
-Fl_Input2	*txt_309_comm_msg[60]  = {(Fl_Input2 *)0};
+Fl_Input2	*txt_309_comm_time[34] = {(Fl_Input2 *)0};
+Fl_Button	*btn_309_comm_time[34] = {(Fl_Button *)0};
+Fl_Input2	*txt_309_comm_from[34] = {(Fl_Input2 *)0};
+Fl_Input2	*txt_309_comm_to[34]   = {(Fl_Input2 *)0};
+Fl_Input2	*txt_309_comm_msg[34]  = {(Fl_Input2 *)0};
 
-int bptr[60] = {\
+int bptr[34] = {\
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, \
 10,11,12,13,14,15,16,17,18,19, \
 20,21,22,23,24,25,26,27,28,29, \
-30,31,32,33,34,35,36,37,38,39, \
-40,41,42,43,44,45,46,47,48,49, \
-50,51,52,53,54,55,56,57,58,59, \
- };
+30,31,32,33 };
 
 void cb_309_comm_time_changed(Fl_Widget *w, void *d)
 {
 	int p = *(int *)d;
-	txt_309_comm_time[p]->value(szTime());
+	txt_309_comm_time[p]->value(szTime(progStatus.UTC));
 	ics_changed(txt_309_comm_time[p], d);
 }
 
@@ -272,7 +269,7 @@ void create_ics309_tab()
 				o->type(3);
 				o->box(FL_DOWN_BOX);
 				o->color((Fl_Color)215);
-				for (int i = 0; i < 60; i++) {
+				for (int i = 0; i < 34; i++) {
 
 					txt_309_comm_time[i] = new Fl_Input2(5, Y+52 + i*22, 50, 22);
 					txt_309_comm_time[i]->tooltip(_(""));
